@@ -80,7 +80,8 @@ print.findFn <- function(x,
   Ocall <- attr(x, "call")
   Oc0 <- deparse(Ocall)
   Oc. <- gsub('\"', "'", Oc0)
-  if(Oc.=='NULL')Oc. <- '...'
+#  if(Oc.=='NULL')Oc. <- '...'
+  Oc.[Oc.=='NULL'] <- '...'
   Oc1 <- paste(cl, "<-", paste(Oc., collapse=''))
 #  Oc2 <- paste0('For a package summary:  ', 
 #  Oc2 <- paste0('For more info, call installPackages', 
