@@ -37,7 +37,7 @@ writeFindFn2xls <- function(x,
 ##
 ## Don't write a file for CRAN 
 ##
-  if(fda::CRAN()){
+  if(CRAN()){
     cat('write nothing on CRAN')
   } else {
 ##
